# Kleio sources directory

Files here contain the transcription of historical data and the results of the processing of those files by `timelink`.

Types of files in this directory:

* Files in Kleio format, with a `.cli` or `.kleio` extension. Kleio files are text files in a special notation that contain information from historical sources. They are the source of data for timelink databases.
* XML files with extension `.xml` contain the data generated by processing ("translasting") the Kleio files. These files are imported in timelink databases.
* Report files with extension `.rpt` contain human readable information about the translation of Kleio source files.
* Other files are generated as part of the translation process and are used by the system:
  * .err file the number of errors and warnings generated during the translation process
  * .files.json a machine readable list of the files involved in a translation process, number of errors and warnings.
  * .old, .org are files with earlier versions of the kleio files, kept for backup purposes.

The user edits kleio files and checks .rpt files for errors. All the other files are for machine processing.



